@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.71';
+our $VERSION = '0.1.72';
 
 use base 'Exporter'; 
 
@@ -62,17 +62,19 @@ sub make_http_request {
 
         $curl_cmd.=' -f'  unless ignore_http_err();
 
-        my $curl_runner = "$curl_cmd  -i -o $content_file --stderr $content_file.stderr '$hostname$resource'";
+        my $curl_runner = "$curl_cmd -i -o $content_file --stderr $content_file.stderr '$hostname$resource'";
 
         my $st = execute_with_retry("$curl_runner && test -f $content_file", get_prop('try_num'));
 
         if ($st) {
 
             ok(1, "$http_method $hostname$resource succeeded");
+            diag($curl_runner) if debug_mod12();
 
         }elsif(ignore_http_err()){
 
             ok(1, "$http_method $hostname$resource failed, still continue due to ignore_http_err set to 1");
+            diag($curl_runner) if debug_mod12();
 
         }else{
 
@@ -350,7 +352,9 @@ Here is the list of I<predefined> file names for a http methods files:
 
 =head1 Hostname / IP Address
 
-You need to define hostname or ip address to send request to. Just write it up to a special file  called `host' and swat will use it.
+You need to define hostname or ip address to send request to. 
+
+Just write it up to a special file  called `host' and swat will use it.
 
     echo 'app.local' > host
 
@@ -471,16 +475,6 @@ POST FOO/BAR
 
 =back
 
-Use `test_file' variable to execute a subset of swat stories:
-
-    # run a single story
-    test_file=FOO/get swat example/my-app 127.0.0.1
-    
-    # run all `FOO/*' stories:
-    test_file=FOO/ swat example/my-app 127.0.0.1
-
-Test_file variable should point to a resource(s) path and be relative to project root dir, also it should not contain extension part - `.txt'
-
 
 =head1 Swat check lists
 
@@ -1315,16 +1309,18 @@ another test / reporting systems, follow TAP documentation to get more on this.
 
 Here is example for converting swat tests into JUNIT format:
 
-    swat --formatter TAP::Formatter::JUnit
+    swat --prove '--formatter TAP::Formatter::JUnit'
 
 
 =head1 Prove settings
 
-Swat utilize L<prove utility|http://search.cpan.org/perldoc?prove> to run tests, all prove related parameters are passed as is to prove.
+Swat utilize L<prove utility|http://search.cpan.org/perldoc?prove> to run tests, 
+all prove related parameters could be passed via `--prove' option to prove runner.
+
 Here are some examples:
 
-    swat -Q # don't show anythings unless test summary
-    swat -q -s # run prove tests in random and quite mode
+    swat --prove -Q # don't show anythings unless test summary
+    swat --prove '-q -s' # run prove tests in random and quite mode
 
 
 =head1 Misc settings
@@ -1358,7 +1354,91 @@ Default value is `0' ( do not clear cache ).
 
 Once swat is installed you get swat client at the `PATH':
 
-    swat <project_root_dir> <host:port> <prove settings>
+    swat [project_root_dir] [host:port] [swat_command_line_options]
+
+All command parameters are optional.
+
+=over
+
+=item *
+
+B<project_root_dir> - swat project root directory
+
+
+=back
+
+In case you don't set one, swat assume it equal to current working directory. Examples:
+
+    # setup project root directory explicitely
+    swat /foo/bar/baz
+    
+    # project root directory is CWD
+    swat 
+
+=over
+
+=item *
+
+B<host> - basic URL of tested application, should be in curl compatible format
+
+
+=back
+
+In case host parameter is missing , swat tries to read it up from `host' file. Examples:
+
+    # setup host explicitely
+    swat /foo/bar/baz 127.0.0.1
+    
+    # host entry gets read from CWD/host file 
+    swat /foo/bar/baz
+     
+    # project root directory is CWD
+    # host entry gets read from CWD/host file 
+    swat
+
+List of swat command line options:
+
+=over
+
+=item *
+
+B<--prove|prove-opts> - see L<prove settings|prove-settings>
+
+
+=item *
+
+B<-t|--test> (could me many) - run subset of swat stories
+
+
+=back
+
+Use `-t' options to execute a subset of swat stories:
+
+    # run `FOO/*' stories
+    swat example/my-app 127.0.0.1 -t FOO/
+
+=over
+
+=item *
+
+`-t' option should point to a resource(s) path and be relative to the project root directory 
+
+
+=item *
+
+`-t' option should not contain extension part - `.txt'
+
+
+=item *
+
+it is possible to use more than one `t' options
+
+
+=back
+
+For example:
+
+    -t FOO/BAR -t BAR -t FOO/BAZ  
 
 
 =head1 Examples
